//
//  ViewController.m
//  speechtest
//
//  Created by Kim Ki-soo on 13. 7. 26..
//  Copyright (c) 2013년 Kim Ki-soo. All rights reserved.
//

#import "ViewController.h"
#import <AVFoundation/AVFoundation.h>

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    // 음성인식 델리게이트 설정
    [[SpeechRecognizer sharedObject] setDelegate:self];
}

- (IBAction)listenAction:(id)sender {
    
    // 음성 녹음 시작
    [[SpeechRecognizer sharedObject] start];
}

- (IBAction)stopAction:(id)sender {
    
    // 음성 녹음 정지 -> 음성인식으로 전달됨
    [[SpeechRecognizer sharedObject] stop];
}

// 음성인식 상태
- (void)speechRecognizerStatus:(SpeechRecognizerStatus)status {
    
    // UI를 업데이트 할 땐 코드를 메인큐에서 실행해야 한다. (textViewResult.text 변경)
    dispatch_async(dispatch_get_main_queue(), ^{
    
        switch (status) {
                
            case SpeechRecognizerStatusError:
                textViewResult.text = @"에러";
                break;
                
            case SpeechRecognizerStatusWait:
                textViewResult.text = @"준비중";
                break;
                
            case SpeechRecognizerStatusListening:
                textViewResult.text = @"듣는중...";
                break;
                
            case SpeechRecognizerStatusProcessing:
                textViewResult.text = @"처리중...";
                break;
                
            case SpeechRecognizerStatusRecognition:
                textViewResult.text = @"인식중...";
                break;

        }
        
    });
    
}

// 음성 인식 결과
- (void)speechRecognizerResult:(NSDictionary*)result {
    
    // 0 = 이면 성공
    NSLog(@"code = %d", [[result objectForKey:@"code"] intValue]);
    
    // 인식된 텍스트, 인식못하면 텍스트 길이 = 0
    NSLog(@"text = %@", [result objectForKey:@"text"]);
    
    // UI를 업데이트 할 땐 코드를 메인큐에서 실행해야 한다.
    dispatch_async(dispatch_get_main_queue(), ^{
        textViewResult.text = [result objectForKey:@"text"];
    });
}

// 마이크로 입력된 음성의 세기
- (void)speechRecognizerMicPower:(float)power {
    
    // UI를 업데이트 할 땐 코드를 메인큐에서 실행해야 한다.
    dispatch_async(dispatch_get_main_queue(), ^{
        progressView.progress = power * 3;
    });
}

@end
